==> civicrm_5.3.1+dfsg.orig-wordpress.tar.xz: civicrm/assets/templates/civicrm.shortcode.php <==
<?php

/*
 +--------------------------------------------------------------------+
 | CiviCRM version 4.7                                                |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2018                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the GNU Affero General Public License           |
 | Version 3, 19 November 2007 and the CiviCRM Licensing Exception.   |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the GNU Affero General Public License for more details.        |
 |                                                                    |
 | You should have received a copy of the GNU Affero General Public   |
 | License and the CiviCRM Licensing Exception along                  |
 | with this program; if not, contact CiviCRM LLC                     |
 | at info[AT]civicrm[DOT]org. If you have questions about the        |
 | GNU Affero General Public License or the licensing of CiviCRM,     |
 | see the CiviCRM license FAQ at http://civicrm.org/licensing        |
 +--------------------------------------------------------------------+
*/

/**
 *
 * @package CRM
 * @copyright CiviCRM LLC (c) 2004-2018
 *
 */

?>

<div class="crm-container crm-public<?php echo $class; ?>">

  <?php if ( $show_title ) { ?>
    <h2><?php echo $title; ?></h2>
  <?php } ?>

  <?php if ( $description ) { ?>
    <div class="civi-description"><?php echo $description; ?></div>
  <?php } ?>

  <p><?php echo $more_link; ?></p>

  <?php if ( $empowered_enabled ) { ?>
  <div class="crm-public-footer">
    <?php echo $footer; ?>
  </div>
  <?php } ?>

</div>

==> civicrm_5.11.0+dfsg.orig-wordpress.tar.xz: civicrm/assets/templates/civicrm.shortcode.php <==
<?php

/*
 +--------------------------------------------------------------------+
 | CiviCRM version 5                                                  |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2019                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the GNU Affero General Public License           |
 | Version 3, 19 November 2007 and the CiviCRM Licensing Exception.   |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the GNU Affero General Public License for more details.        |
 |                                                                    |
 | You should have received a copy of the GNU Affero General Public   |
 | License and the CiviCRM Licensing Exception along                  |
 | with this program; if not, contact CiviCRM LLC                     |
 | at info[AT]civicrm[DOT]org. If you have questions about the        |
 | GNU Affero General Public License or the licensing of CiviCRM,     |
 | see the CiviCRM license FAQ at http://civicrm.org/licensing        |
 +--------------------------------------------------------------------+
*/

/**
 *
 * @package CRM
 * @copyright CiviCRM LLC (c) 2004-2019
 *
 */

?>

<div class="crm-container crm-public<?php echo $class; ?>">

  <?php if ( $show_title ) { ?>
    <h2><?php echo $title; ?></h2>
  <?php } ?>

  <?php if ( $description ) { ?>
    <div class="civi-description"><?php echo $description; ?></div>
  <?php } ?>

  <p><?php echo $more_link; ?></p>

  <?php if ( $empowered_enabled ) { ?>
  <div class="crm-public-footer">
    <?php echo $footer; ?>
  </div>
  <?php } ?>

</div>
